==> esphome-1.18.0b3.tar.gz: esphome-1.18.0b3/esphome/components/ssd1351_base/__init__.py <==
import esphome.codegen as cg
import esphome.config_validation as cv
from esphome import pins
from esphome.components import display
from esphome.const import CONF_BRIGHTNESS, CONF_LAMBDA, CONF_MODEL, CONF_RESET_PIN
from esphome.core import coroutine

CODEOWNERS = ["@kbx81"]

ssd1351_base_ns = cg.esphome_ns.namespace("ssd1351_base")
SSD1351 = ssd1351_base_ns.class_("SSD1351", cg.PollingComponent, display.DisplayBuffer)
SSD1351Model = ssd1351_base_ns.enum("SSD1351Model")

MODELS = {
    "SSD1351_128X96": SSD1351Model.SSD1351_MODEL_128_96,
    "SSD1351_128X128": SSD1351Model.SSD1351_MODEL_128_128,
}

SSD1351_MODEL = cv.enum(MODELS, upper=True, space="_")

SSD1351_SCHEMA = display.FULL_DISPLAY_SCHEMA.extend(
    {
        cv.Required(CONF_MODEL): SSD1351_MODEL,
        cv.Optional(CONF_RESET_PIN): pins.gpio_output_pin_schema,
        cv.Optional(CONF_BRIGHTNESS, default=1.0): cv.percentage,
    }
).extend(cv.polling_component_schema("1s"))


@coroutine
def setup_ssd1351(var, config):
    yield cg.register_component(var, config)
    yield display.register_display(var, config)

    cg.add(var.set_model(config[CONF_MODEL]))
    if CONF_RESET_PIN in config:
        reset = yield cg.gpio_pin_expression(config[CONF_RESET_PIN])
        cg.add(var.set_reset_pin(reset))
    if CONF_BRIGHTNESS in config:
        cg.add(var.init_brightness(config[CONF_BRIGHTNESS]))
    if CONF_LAMBDA in config:
        lambda_ = yield cg.process_lambda(
            config[CONF_LAMBDA], [(display.DisplayBufferRef, "it")], return_type=cg.void
        )
        cg.add(var.set_writer(lambda_))

==> esphome-2022.9.0b4.tar.gz: esphome-2022.9.0b4/esphome/components/ssd1351_base/__init__.py <==
import esphome.codegen as cg
import esphome.config_validation as cv
from esphome import pins
from esphome.components import display
from esphome.const import CONF_BRIGHTNESS, CONF_LAMBDA, CONF_MODEL, CONF_RESET_PIN

CODEOWNERS = ["@kbx81"]

ssd1351_base_ns = cg.esphome_ns.namespace("ssd1351_base")
SSD1351 = ssd1351_base_ns.class_("SSD1351", cg.PollingComponent, display.DisplayBuffer)
SSD1351Model = ssd1351_base_ns.enum("SSD1351Model")

MODELS = {
    "SSD1351_128X96": SSD1351Model.SSD1351_MODEL_128_96,
    "SSD1351_128X128": SSD1351Model.SSD1351_MODEL_128_128,
}

SSD1351_MODEL = cv.enum(MODELS, upper=True, space="_")

SSD1351_SCHEMA = display.FULL_DISPLAY_SCHEMA.extend(
    {
        cv.Required(CONF_MODEL): SSD1351_MODEL,
        cv.Optional(CONF_RESET_PIN): pins.gpio_output_pin_schema,
        cv.Optional(CONF_BRIGHTNESS, default=1.0): cv.percentage,
    }
).extend(cv.polling_component_schema("1s"))


async def setup_ssd1351(var, config):
    await cg.register_component(var, config)
    await display.register_display(var, config)

    cg.add(var.set_model(config[CONF_MODEL]))
    if CONF_RESET_PIN in config:
        reset = await cg.gpio_pin_expression(config[CONF_RESET_PIN])
        cg.add(var.set_reset_pin(reset))
    if CONF_BRIGHTNESS in config:
        cg.add(var.init_brightness(config[CONF_BRIGHTNESS]))
    if CONF_LAMBDA in config:
        lambda_ = await cg.process_lambda(
            config[CONF_LAMBDA], [(display.DisplayBufferRef, "it")], return_type=cg.void
        )
        cg.add(var.set_writer(lambda_))
